import subprocess
import sys

def main():
    if len(sys.argv) < 3:
        print ("Usage: python3 " + sys.argv[0] + " ssid wpa_passphrase")
        sys.exit(1)
        return
    if len(sys.argv[2]) < 8:
        print ("wpa_passphrase length must be greater than  7")
        sys.exit(1)
        return

    install = subprocess.run(['apt-get', 'install', '-y', 'hostapd', 'dnsmasq'])
    stop_hostapd = subprocess.run(['systemctl', 'stop', 'hostapd'])
    stop_dnsmasq = subprocess.run(['systemctl', 'stop', 'dnsmasq'])

    subprocess.run(['cp', '/etc/dhcpcd.conf', '/etc/dhcpcd.conf.pre_wap'])
    with open('/etc/dhcpcd.conf', 'a') as dhcpcd_conf:
        lines = [
        'interface wlan0\n',
        'static ip_address=192.168.0.10/24\n',
        'denyinterfaces eth0\n',
        'denyinterfaces wlan0\n']
        dhcpcd_conf.writelines(lines)

    subprocess.run(['mv', '/etc/dnsmasq.conf', '/etc/dnsmasq.conf.pre_wap'])
    with open('/etc/dnsmasq.conf', 'w') as dnsmasq_conf:
        lines = [
        'interface=wlan0\n',
        'dhcp-range=192.168.0.11,192.168.0.30,255.255.255.0,24h\n']
        dnsmasq_conf.writelines(lines)

    with open('/etc/hostapd/hostapd.conf', 'w') as hostapd_conf:
        lines = []
        lines.append('interface=wlan0\n')
        lines.append('bridge=br0\n')
        lines.append('hw_mode=g\n')
        lines.append('channel=7\n')
        lines.append('wmm_enabled=0\n')
        lines.append('macaddr_acl=0\n')
        lines.append('auth_algs=1\n')
        lines.append('ignore_broadcast_ssid=0\n')
        lines.append('wpa=2\n')
        lines.append('wpa_key_mgmt=WPA-PSK\n')
        lines.append('wpa_pairwise=TKIP\n')
        lines.append('ssid=' + sys.argv[1] + '\n')
        lines.append('wpa_passphrase=' + sys.argv[2] + '\n')
        hostapd_conf.writelines(lines)

    subprocess.run(['cp', '/etc/default/hostapd',
    '/etc/default/hostapd.pre_wap'])
    with open('/etc/default/hostapd', 'a') as hostapd_d:
        hostapd_d.writelines(['\n', 'DAEMON_CONF=/etc/hostapd/hostapd.conf\n'])

    subprocess.run(['cp', '/etc/sysctl.conf',
    '/etc/sysctl.conf.pre_wap'])

    lines = None
    with open('/etc/sysctl.conf', 'r+') as sysctl_conf:
        lines = sysctl_conf.readlines()
        try:
            ind = lines.index('#net.ipv4.ip_forward=1\n')
            lines[ind] = 'net.ipv4.ip_forward=1\n'
            sysctl_conf.seek(0)
            sysctl_conf.writelines(lines)
        except:
            pass

    subprocess.run(['iptables', '-t', 'nat',
    '-A', 'POSTROUTING', '-o', 'eth0', '-j', 'MASQUERADE'])
    subprocess.run(['cp', '/etc/iptables.ipv4.nat', '/etc/iptables.ipv4.nat.pre_wap'])
    subprocess.run(['sh', '-c', 'iptables-save > /etc/iptables.ipv4.nat'])

    subprocess.run(['cp', '/etc/rc.local', '/etc/rc.local.pre_wap'])
    with open('/etc/rc.local', 'r+') as rc_local:
        lines = rc_local.readlines()
        ind = lines.index('exit 0\n')
        lines.insert(ind, 'iptables-restore < /etc/iptables.ipv4.nat\n')
        rc_local.seek(0)
        rc_local.writelines(lines)

    subprocess.run(['apt-get', 'install', '-y', 'bridge-utils'])
    subprocess.run(['brctl', 'addbr', 'br0'])
    subprocess.run(['brctl', 'addif', 'br0', 'eth0'])

    subprocess.run(['cp', '/etc/network/interfaces', '/etc/network/interfaces.pre_wap'])
    with open('/etc/network/interfaces', 'a') as interfaces:
        lines = ['\n', 'auto br0\n', 'iface br0 inet manual\n', 'bridge_ports eth0 wlan0\n']
        interfaces.writelines(lines)

    subprocess.run(['systemctl', 'unmask', 'hostapd'])
    subprocess.run(['systemctl', 'enable', 'hostapd'])

    return;

if __name__ == "__main__":
    main()

